@@ -13,7 +13,7 @@
 #' @param cex The magnification to be used for plotting symbols.
 #' @param min.cex Minimal magnification for plotting symbols.
 #' @param max.cex Maximal magnification for plotting symbols.
-#' @param pch The plotting symbol used for individual studies.
+#' @param pch The plotting symbol(s) used for individual studies.
 #' @param col A vector with colour of plotting symbols.
 #' @param bg A vector with background colour of plotting symbols (only
 #'   used if \code{pch} in \code{21:25}).
@@ -28,7 +28,6 @@
 #' @param pos.studlab Position of study labels, see argument
 #'   \code{pos} in \code{\link{text}}.
 #' @param offset Offset for study labels (see \code{\link{text}}).
-#' @param offset Offset for study labels (see \code{\link{text}}).
 #' @param regline A logical indicating whether a regression line
 #'   should be added to the bubble plot.
 #' @param col.line Colour for the meta-regression line.
@@ -48,7 +47,9 @@
 #'   probabilities.
 #' @param irscale A numeric defining a scaling factor for printing of
 #'   incidence rates.
-#' @param axes A logical indicating whether axes should be printed.
+#' @param axes Either a logical or a character string equal to \code{"x"},
+#'   \code{"y"} or \code{"xy"} indicating whether x- and y-axis should be
+#'   printed.
 #' @param box A logical indicating whether a box should be printed.
 #' @param \dots Graphical arguments as in \code{par} may also be
 #'   passed as arguments.
@@ -179,7 +180,17 @@ bubble.metareg <- function(x,
   else
     irscale <- 1
   #
-  chklogical(axes)
+  if (!is.character(axes)) {
+    chklogical(axes)
+    axis.x <- axis.y <- axes
+  }
+  else {
+    axes <- setchar(axes, c("x", "y", "xy"))
+    #
+    axis.x <- grepl("x", axes)
+    axis.y <- grepl("y", axes)
+  }
+  #
   chklogical(box)
   
   
@@ -195,7 +206,7 @@ bubble.metareg <- function(x,
   sm <- m1$sm
 
   log.y <- backtransf &&
-    (is_relative_effect(sm) ||
+    (is_relative_effect(sm) || is_log_effect(sm) ||
      (!is.null(m1$func.backtransf) && m1$func.backtransf == "exp"))
   #
   if (log.y) {
@@ -229,8 +240,8 @@ bubble.metareg <- function(x,
       stop("Length of argument 'studlab' must be the same as ",
            "number of studies in meta-analysis.")
   }
-
-
+  
+  
   charform <- as.character(x$.meta$formula)[2]
   splitform <- strsplit(charform, " ")[[1]]
   covar.name <- splitform[1]
@@ -315,14 +326,40 @@ bubble.metareg <- function(x,
   #
   ys <- TE
   #
+  if (backtransf & !log.y) {
+    if (!is.null(m1$func.backtransf))
+      func.backtransf <- m1$func.backtransf
+    else if (sm == "PLOGIT")
+      func.backtransf <- logit2p
+    else if (sm == "PAS")
+      func.backtransf <- asin2p
+    else if (sm == "IRS")
+      func.backtransf <- function(x) x^2
+    else if (sm == "ZCOR")
+      func.backtransf <- z2cor
+    else
+      func.backtransf <- I
+    #
+    ys <- do.call(func.backtransf, list(ys))
+  }
+  #
   if (missing(ylim))
     ylim <- scale * range(ys)
   #
   if (missing(ylab)) {
     ylab <- xlab(sm, backtransf, func.transf = m1$func.transf,
                  func.backtransf = m1$func.backtransf)
-    if (sm == "PRAW")
-      ylab <- "Proportion"
+    #
+    if (ylab == "") {
+      if (sm == "PRAW" | (backtransf & sm %in% c("PLN", "PAS", "PLOGIT")))
+        ylab <- "Proportion"
+      else if (sm == "IR" | (backtransf & sm %in% c("IRLN", "IRS")))
+        ylab <- "Incidence Rate"
+      else if (sm == "MRAW" | (backtransf & sm %in% c("IRLN", "IRS")))
+        ylab <- "Incidence Rate"
+      else if (sm == "COR" | (backtransf & sm == "ZCOR"))
+        ylab <- "Correlation"
+    }
   }
   
   
@@ -386,6 +423,11 @@ bubble.metareg <- function(x,
   studlab <- studlab[o]
   cexs <- cexs[o]
   #
+  if (length(pch) > 1)
+    pchs <- pch[o]
+  else
+    pchs <- rep(pch, length(o))
+  #
   if (length(col) > 1)
     cols <- col[o]
   else
@@ -419,11 +461,12 @@ bubble.metareg <- function(x,
       ys.i <- ys[sel]
       studlab.i <- studlab[sel]
       cexs.i <- cexs[sel]
+      pch.i <- pchs[sel]
       col.i <- cols[sel]
       bg.i <- bgs[sel]
       #
       plot(xs.i, scale * ys.i,
-           pch = pch, cex = cexs.i,
+           pch = pch.i, cex = cexs.i,
            xlab = xlab, ylab = ylab, xlim = xlim, ylim = ylim,
            type = "n", axes = FALSE, log = log, ...)
       #
@@ -434,24 +477,29 @@ bubble.metareg <- function(x,
       # Add regression line
       #
       if (regline) {
-        y.reg <- c(alpha, alpha + coef(x)[i])
+        x.reg <- seq(0, 1, length.out = 500)
+        y.reg <- seq(alpha, alpha + coef(x)[i], length.out = 500)
+        #
         if (log.y)
           y.reg <- scale * exp(y.reg)
-        lines(c(0, 1), y.reg, lty = lty, lwd = lwd, col = col.line)
+        else if (backtransf)
+          y.reg <- scale * do.call(func.backtransf, list(y.reg))
+        #
+        lines(x.reg, y.reg, lty = lty, lwd = lwd, col = col.line)
       }
       #
       for (j in seq_along(xs.i))
-        points(xs.i[j], scale * ys.i[j], cex = cexs.i[j], pch = pch,
+        points(xs.i[j], scale * ys.i[j], cex = cexs.i[j], pch = pch.i[j],
                col = col.i[j], bg = bg.i[j])
       #
       # x-axis
       #
-      if (axes)
+      if (axis.x)
         axis(1, at = 0:1, labels = levs[c(1, i)], ...)
       #
       # y-axis
       #
-      if (axes)
+      if (axis.y)
         axis(2, ...)
       #
       text(xs.i, scale * ys.i, labels = studlab.i, cex = cex.studlab,
@@ -463,7 +511,7 @@ bubble.metareg <- function(x,
   }
   else {
     plot(xs, scale * ys,
-         pch = pch, cex = cexs,
+         pch = pchs, cex = cexs,
          xlab = xlab, ylab = ylab, xlim = xlim, ylim = ylim,
          type = "n", axes = FALSE, log = log, ...)
     #
@@ -474,24 +522,28 @@ bubble.metareg <- function(x,
     # Add regression line
     #
     if (regline) {
-      x.reg <- c(xlim[1], xlim[2])
-      y.reg <- c(alpha + beta * xlim[1], alpha + beta * xlim[2])
-      if (log == "y")
+      x.reg <- seq(xlim[1], xlim[2], length.out = 500)
+      y.reg <- seq(alpha + beta * xlim[1], alpha + beta * xlim[2],
+                   length.out = 500)
+      #
+      if (log.y)
         y.reg <- scale * exp(y.reg)
+      else if (backtransf)
+        y.reg <- scale * do.call(func.backtransf, list(y.reg))
       #
       lines(x.reg, y.reg, lty = lty, lwd = lwd, col = col.line)
     }
     #
-    points(xs, scale * ys, cex = cexs, pch = pch, col = cols, bg = bgs)
+    points(xs, scale * ys, cex = cexs, pch = pchs, col = cols, bg = bgs)
     #
     # x-axis
     #
-    if (axes)
+    if (axis.x)
       axis(1, ...)
     #
     # y-axis
     #
-    if (axes)
+    if (axis.y)
       axis(2, ...)
     #
     text(xs, scale * ys, labels = studlab, cex = cex.studlab,
