@@ -44,8 +44,7 @@
 #' \code{\link{metainc}}. Accordingly, a meta-analysis object created
 #' with one of these functions can be provided as argument
 #' \code{treat1}. It is also possible to use the longarm function with
-#' an R objected created with \code{\link{pairwise}} from R
-#' package \bold{netmeta}.
+#' an R objected created with \code{\link{pairwise}}.
 #'
 #' Otherwise, arguments \code{treat1} and \code{treat2} are mandatory
 #' to identify the individual treatments and, depending on the
@@ -382,9 +381,11 @@ longarm <- function(treat1, treat2,
       missing.treat2 <- FALSE
     }
     else if (!missing.treat1 && !missing.treat2 &&
-             length(treat1) == 1 && length(treat2) == 1) {
-      treat1 <- rep(treat1, k.all)
-      treat2 <- rep(treat2, k.all)
+             (length(treat1) == 1 | length(treat2) == 1)) {
+      if (length(treat1) == 1)
+        treat1 <- rep(treat1, k.all)
+      if (length(treat2) == 1)
+        treat2 <- rep(treat2, k.all)
     }
     ##
     if (missing.treat2)
@@ -581,7 +582,8 @@ longarm <- function(treat1, treat2,
   
   
   attr(res, "type") <- type
-  attr(res, "longarm") <- TRUE
-  ##
+  #
+  class(res) <- unique(c("longarm", class(res)))
+  #
   res
 }
