@@ -29,8 +29,14 @@
 #' @param method.tau.ci A character string indicating which method is
 #'   used to estimate the confidence interval of \eqn{\tau^2} and
 #'   \eqn{\tau} (see \code{\link{meta-package}}).
+#' @param level.hetstat The level used to calculate confidence intervals
+#'   for heterogeneity statistics.
 #' @param tau.common A logical indicating whether tau-squared should
 #'   be the same across subgroups.
+#' @param method.I2 A character string indicating which method is
+#'   used to estimate the heterogeneity statistic I\eqn{^2}. Either
+#'   \code{"Q"} or \code{"tau2"}, can be abbreviated
+#'   (see \code{\link{meta-package}}).
 #' @param level.ma The level used to calculate confidence intervals
 #'   for meta-analysis estimates.
 #' @param method.random.ci A character string indicating which method
@@ -94,6 +100,10 @@
 #' @param title Title of meta-analysis / systematic review.
 #' @param complab Comparison label.
 #' @param outclab Outcome label.
+#' @param col.label.left The colour of the graph label on the left side of
+#'   the null effect.
+#' @param col.label.right The colour of the graph label on the right side of
+#'   the null effect.
 #' @param keepdata A logical indicating whether original data (set)
 #'   should be kept in meta object.
 #' @param warn A logical indicating whether warnings should be printed
@@ -107,10 +117,9 @@
 #' Cochrane intervention reviews are based on the comparison of two
 #' interventions. Each Cochrane intervention review can have a
 #' variable number of comparisons. For each comparison, a variable
-#' number of outcomes can be define. For each outcome, a seperate
+#' number of outcomes can be define. For each outcome, a separate
 #' meta-analysis is conducted. Review Manager 5 (RevMan 5) was the
-#' software used for preparing and maintaining Cochrane Reviews
-#' (\url{https://training.cochrane.org/online-learning/core-software/revman}).
+#' software used for preparing and maintaining Cochrane Reviews.
 #' 
 #' This wrapper function can be used to perform meta-analysis for a
 #' single outcome of a Cochrane intervention review. Internally, R
@@ -186,8 +195,11 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                    ##
                    method.tau = "DL",
                    method.tau.ci = gs("method.tau.ci"),
+                   level.hetstat = gs("level.hetstat"),
                    tau.common = FALSE,
-                   ##
+                   #
+                   method.I2 = gs("method.I2"),
+                   #
                    level.ma = gs("level.ma"),
                    method.random.ci = "classic",
                    adhoc.hakn.ci = gs("adhoc.hakn.ci"),
@@ -218,7 +230,10 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                    text.w.random = gs("text.w.random"),
                    ##
                    title, complab, outclab,
-                   ##
+                   #
+                   col.label.left = gs("col.label.left"),
+                   col.label.right = gs("col.label.right"),
+                   #
                    keepdata = gs("keepdata"),
                    warn = FALSE,
                    warn.deprecated = gs("warn.deprecated"),
@@ -296,7 +311,9 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
     method.tau.ci <- if (method.tau == "DL") "J" else "QP"
   method.tau.ci <- setchar(method.tau.ci, gs("meth4tau.ci"))
   chklogical(tau.common)
-  ##
+  #
+  method.I2 <- setchar(method.I2, gs("meth4i2"))
+  #
   chklogical(prediction)
   chklevel(level.predict)
   chklogical(prediction.subgroup)
@@ -500,8 +517,11 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                       prediction = prediction,
                       ##
                       method.tau = method.tau, method.tau.ci = method.tau.ci,
+                      level.hetstat = level.hetstat,
                       tau.common = tau.common,
-                      ##
+                      #
+                      method.I2 = method.I2,
+                      #
                       level.ma = level.ma,
                       method.random.ci = method.random.ci,
                       adhoc.hakn.ci = adhoc.hakn.ci,
@@ -527,9 +547,12 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                       ##
                       title = title,
                       complab = complab, outclab = outclab,
+                      #
                       label.e = label.e, label.c = label.c,
                       label.left = label.left, label.right = label.right,
-                      ##
+                      col.label.left = col.label.left,
+                      col.label.right = col.label.right,
+                      #
                       RR.Cochrane = TRUE,
                       Q.Cochrane = Q.Cochrane,
                       ##
@@ -545,8 +568,11 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                       prediction = prediction,
                       ##
                       method.tau = method.tau, method.tau.ci = method.tau.ci,
+                      level.hetstat = level.hetstat,
                       tau.common = tau.common,
-                      ##
+                      #
+                      method.I2 = method.I2,
+                      #
                       level.ma = level.ma,
                       method.random.ci = method.random.ci,
                       adhoc.hakn.ci = adhoc.hakn.ci,
@@ -572,9 +598,12 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                       ##
                       title = title,
                       complab = complab, outclab = outclab,
+                      #
                       label.e = label.e, label.c = label.c,
                       label.left = label.left, label.right = label.right,
-                      ##
+                      col.label.left = col.label.left,
+                      col.label.right = col.label.right,
+                      #
                       RR.Cochrane = TRUE,
                       Q.Cochrane = Q.Cochrane,
                       ##
@@ -592,8 +621,11 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                      prediction = prediction,
                      ##
                      method.tau = method.tau, method.tau.ci = method.tau.ci,
+                     level.hetstat = level.hetstat,
                      tau.common = tau.common,
-                     ##
+                     #
+                     method.I2 = method.I2,
+                     #
                      level.ma = level.ma,
                      method.random.ci = method.random.ci,
                      adhoc.hakn.ci = adhoc.hakn.ci,
@@ -617,9 +649,12 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                      ##
                      title = title,
                      complab = complab, outclab = outclab,
+                     #
                      label.e = label.e, label.c = label.c,
                      label.left = label.left, label.right = label.right,
-                     ##
+                     col.label.left = col.label.left,
+                     col.label.right = col.label.right,
+                     #
                      keepdata = keepdata)
     ##
     if (type == "P")
@@ -633,8 +668,11 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                     prediction = prediction,
                     ##
                     method.tau = method.tau, method.tau.ci = method.tau.ci,
+                    level.hetstat = level.hetstat,
                     tau.common = tau.common,
-                    ##
+                    #
+                    method.I2 = method.I2,
+                    #
                     level.ma = level.ma,
                     method.random.ci = method.random.ci,
                     adhoc.hakn.ci = adhoc.hakn.ci,
@@ -660,9 +698,12 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                     ##
                     title = title,
                     complab = complab, outclab = outclab,
+                    #
                     label.e = label.e, label.c = label.c,
                     label.left = label.left, label.right = label.right,
-                    ##
+                    col.label.left = col.label.left,
+                    col.label.right = col.label.right,
+                    #
                     keepdata = keepdata)
     ##
     if (type == "I" & method != "Peto")
@@ -676,8 +717,11 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                     prediction = prediction,
                     ##
                     method.tau = method.tau, method.tau.ci = method.tau.ci,
+                    level.hetstat = level.hetstat,
                     tau.common = tau.common,
-                    ##
+                    #
+                    method.I2 = method.I2,
+                    #
                     level.ma = level.ma,
                     method.random.ci = method.random.ci,
                     adhoc.hakn.ci = adhoc.hakn.ci,
@@ -706,9 +750,12 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                     ##
                     title = title,
                     complab = complab, outclab = outclab,
+                    #
                     label.e = label.e, label.c = label.c,
                     label.left = label.left, label.right = label.right,
-                    ##
+                    col.label.left = col.label.left,
+                    col.label.right = col.label.right,
+                    #
                     keepdata = keepdata)
     ##
     if (type == "I" & method == "Peto")
@@ -722,8 +769,11 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                     prediction = prediction,
                     ##
                     method.tau = method.tau, method.tau.ci = method.tau.ci,
+                    level.hetstat = level.hetstat,
                     tau.common = tau.common,
-                    ##
+                    #
+                    method.I2 = method.I2,
+                    #
                     level.ma = level.ma,
                     method.random.ci = method.random.ci,
                     adhoc.hakn.ci = adhoc.hakn.ci,
@@ -749,9 +799,12 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                     ##
                     title = title,
                     complab = complab, outclab = outclab,
+                    #
                     label.e = label.e, label.c = label.c,
                     label.left = label.left, label.right = label.right,
-                    ##
+                    col.label.left = col.label.left,
+                    col.label.right = col.label.right,
+                    #
                     keepdata = keepdata)
   }
   else {
@@ -774,8 +827,11 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                       prediction = prediction,
                       ##
                       method.tau = method.tau, method.tau.ci = method.tau.ci,
+                      level.hetstat = level.hetstat,
                       tau.common = tau.common,
-                      ##
+                      #
+                      method.I2 = method.I2,
+                      #
                       level.ma = level.ma,
                       method.random.ci = method.random.ci,
                       adhoc.hakn.ci = adhoc.hakn.ci,
@@ -794,9 +850,12 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                       ##
                       title = title,
                       complab = complab, outclab = outclab,
+                      #
                       label.e = label.e, label.c = label.c,
                       label.left = label.left, label.right = label.right,
-                      ##
+                      col.label.left = col.label.left,
+                      col.label.right = col.label.right,
+                      #
                       RR.Cochrane = TRUE,
                       Q.Cochrane = Q.Cochrane,
                       ##
@@ -812,8 +871,11 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                       prediction = prediction,
                       ##
                       method.tau = method.tau, method.tau.ci = method.tau.ci,
+                      level.hetstat = level.hetstat,
                       tau.common = tau.common,
-                      ##
+                      #
+                      method.I2 = method.I2,
+                      #
                       level.ma = level.ma,
                       method.random.ci = method.random.ci,
                       adhoc.hakn.ci = adhoc.hakn.ci,
@@ -832,8 +894,12 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                       ##
                       title = title,
                       complab = complab, outclab = outclab,
+                      #
                       label.e = label.e, label.c = label.c,
                       label.left = label.left, label.right = label.right,
+                      col.label.left = col.label.left,
+                      col.label.right = col.label.right,
+                      #
                       RR.Cochrane = TRUE,
                       Q.Cochrane = Q.Cochrane,
                       warn = warn, keepdata = keepdata)
@@ -850,8 +916,11 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                      prediction = prediction,
                      ##
                      method.tau = method.tau, method.tau.ci = method.tau.ci,
+                     level.hetstat = level.hetstat,
                      tau.common = tau.common,
-                     ##
+                     #
+                     method.I2 = method.I2,
+                     #
                      level.ma = level.ma,
                      method.random.ci = method.random.ci,
                      adhoc.hakn.ci = adhoc.hakn.ci,
@@ -868,9 +937,12 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                      ##
                      title = title,
                      complab = complab, outclab = outclab,
+                     #
                      label.e = label.e, label.c = label.c,
                      label.left = label.left, label.right = label.right,
-                     ##
+                     col.label.left = col.label.left,
+                     col.label.right = col.label.right,
+                     #
                      keepdata = keepdata)
     ##
     if (type == "P")
@@ -884,8 +956,11 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                     prediction = prediction,
                     ##
                     method.tau = method.tau, method.tau.ci = method.tau.ci,
+                    level.hetstat = level.hetstat,
                     tau.common = tau.common,
-                    ##
+                    #
+                    method.I2 = method.I2,
+                    #
                     level.ma = level.ma,
                     method.random.ci = method.random.ci,
                     adhoc.hakn.ci = adhoc.hakn.ci,
@@ -904,9 +979,12 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                     ##
                     title = title,
                     complab = complab, outclab = outclab,
+                    #
                     label.e = label.e, label.c = label.c,
                     label.left = label.left, label.right = label.right,
-                    ##
+                    col.label.left = col.label.left,
+                    col.label.right = col.label.right,
+                    #
                     keepdata = keepdata)
     ##
     if (type == "I" & method != "Peto")
@@ -920,8 +998,11 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                     prediction = prediction,
                     ##
                     method.tau = method.tau, method.tau.ci = method.tau.ci,
+                    level.hetstat = level.hetstat,
                     tau.common = tau.common,
-                    ##
+                    #
+                    method.I2 = method.I2,
+                    #
                     level.ma = level.ma,
                     method.random.ci = method.random.ci,
                     adhoc.hakn.ci = adhoc.hakn.ci,
@@ -943,9 +1024,12 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                     ##
                     title = title,
                     complab = complab, outclab = outclab,
+                    #
                     label.e = label.e, label.c = label.c,
                     label.left = label.left, label.right = label.right,
-                    ##
+                    col.label.left = col.label.left,
+                    col.label.right = col.label.right,
+                    #
                     keepdata = keepdata)
     ##
     if (type == "I" & method == "Peto")
@@ -959,8 +1043,11 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                     prediction = prediction,
                     ##
                     method.tau = method.tau, method.tau.ci = method.tau.ci,
+                    level.hetstat = level.hetstat,
                     tau.common = tau.common,
-                    ##
+                    #
+                    method.I2 = method.I2,
+                    #
                     level.ma = level.ma,
                     method.random.ci = method.random.ci,
                     adhoc.hakn.ci = adhoc.hakn.ci,
@@ -979,9 +1066,12 @@ metacr <- function(x, comp.no = 1, outcome.no = 1,
                     ##
                     title = title,
                     complab = complab, outclab = outclab,
+                    #
                     label.e = label.e, label.c = label.c,
                     label.left = label.left, label.right = label.right,
-                    ##
+                    col.label.left = col.label.left,
+                    col.label.right = col.label.right,
+                    #
                     keepdata = keepdata)
   }
   
