@@ -102,6 +102,7 @@ subgroup <- function(x, tau.preset = NULL, subgroup.rma,
                        ##
                        method.tau = x$method.tau,
                        method.tau.ci = x$method.tau.ci,
+                       level.hetstat = x$level.hetstat,
                        tau.preset = tau.preset,
                        TE.tau = x$TE.tau,
                        ##
@@ -119,7 +120,28 @@ subgroup <- function(x, tau.preset = NULL, subgroup.rma,
                         cluster =
                           if (!is.null(x$cluster)) x$cluster[sel] else NULL,
                         rho = x$rho,
-                        ##
+                        #
+                        median.e = subsetVar(x$median.e, sel),
+                        q1.e = subsetVar(x$q1.e, sel),
+                        q3.e = subsetVar(x$q3.e, sel),
+                        min.e = subsetVar(x$min.e, sel),
+                        max.e = subsetVar(x$max.e, sel),
+                        #
+                        median.c = subsetVar(x$median.c, sel),
+                        q1.c = subsetVar(x$q1.c, sel),
+                        q3.c = subsetVar(x$q3.c, sel),
+                        min.c = subsetVar(x$min.c, sel),
+                        max.c = subsetVar(x$max.c, sel),
+                        #
+                        method.mean = subsetVar(x$method.mean, sel),
+                        method.sd = subsetVar(x$method.sd, sel),
+                        #
+                        approx.mean.e = subsetVar(x$approx.mean.e, sel),
+                        approx.sd.e = subsetVar(x$approx.sd.e, sel),
+                        #
+                        approx.mean.c = subsetVar(x$approx.mean.c, sel),
+                        approx.sd.c = subsetVar(x$approx.sd.c, sel),
+                        #
                         sm = x$sm,
                         ##
                         pooledvar = x$pooledvar,
@@ -138,6 +160,7 @@ subgroup <- function(x, tau.preset = NULL, subgroup.rma,
                         ##
                         method.tau = x$method.tau,
                         method.tau.ci = x$method.tau.ci,
+                        level.hetstat = x$level.hetstat,
                         tau.preset = tau.preset,
                         TE.tau = x$TE.tau,
                         ##
@@ -166,6 +189,7 @@ subgroup <- function(x, tau.preset = NULL, subgroup.rma,
                        ##
                        method.tau = x$method.tau,
                        method.tau.ci = x$method.tau.ci,
+                       level.hetstat = x$level.hetstat,
                        tau.preset = tau.preset,
                        TE.tau = x$TE.tau,
                        ##
@@ -195,6 +219,7 @@ subgroup <- function(x, tau.preset = NULL, subgroup.rma,
                        ##
                        method.tau = x$method.tau,
                        method.tau.ci = x$method.tau.ci,
+                       level.hetstat = x$level.hetstat,
                        tau.preset = tau.preset,
                        TE.tau = x$TE.tau,
                        ##
@@ -231,6 +256,7 @@ subgroup <- function(x, tau.preset = NULL, subgroup.rma,
                        ##
                        method.tau = x$method.tau,
                        method.tau.ci = x$method.tau.ci,
+                       level.hetstat = x$level.hetstat,
                        tau.preset = tau.preset,
                        TE.tau = x$TE.tau,
                        ##
@@ -244,10 +270,19 @@ subgroup <- function(x, tau.preset = NULL, subgroup.rma,
       meta1 <- metamean(x$n[sel], x$mean[sel], x$sd[sel],
                         studlab = x$studlab[sel],
                         exclude = x$exclude[sel],
-                        cluster =
-                          if (!is.null(x$cluster)) x$cluster[sel] else NULL,
+                        cluster = subsetVar(x$cluster, sel),
                         rho = x$rho,
-                        ##
+                        #
+                        median = subsetVar(x$median, sel),
+                        q1 = subsetVar(x$q1, sel),
+                        q3 = subsetVar(x$q3, sel),
+                        min = subsetVar(x$min, sel),
+                        max = subsetVar(x$max, sel),
+                        method.mean = subsetVar(x$method.mean, sel),
+                        method.sd = subsetVar(x$method.sd, sel),
+                        approx.mean = subsetVar(x$approx.mean, sel),
+                        approx.sd = subsetVar(x$approx.sd, sel),
+                        #
                         sm = x$sm,
                         ##
                         level.ma = x$level.ma,
@@ -261,6 +296,7 @@ subgroup <- function(x, tau.preset = NULL, subgroup.rma,
                         ##
                         method.tau = x$method.tau,
                         method.tau.ci = x$method.tau.ci,
+                        level.hetstat = x$level.hetstat,
                         tau.preset = tau.preset,
                         TE.tau = x$TE.tau,
                         ##
@@ -294,6 +330,7 @@ subgroup <- function(x, tau.preset = NULL, subgroup.rma,
                         ##
                         method.tau = x$method.tau,
                         method.tau.ci = x$method.tau.ci,
+                        level.hetstat = x$level.hetstat,
                         tau.preset = tau.preset,
                         TE.tau = x$TE.tau,
                         ##
@@ -327,6 +364,7 @@ subgroup <- function(x, tau.preset = NULL, subgroup.rma,
                         ##
                         method.tau = x$method.tau,
                         method.tau.ci = x$method.tau.ci,
+                        level.hetstat = x$level.hetstat,
                         tau.preset = tau.preset,
                         TE.tau = x$TE.tau,
                         ##
@@ -550,6 +588,7 @@ subgroup <- function(x, tau.preset = NULL, subgroup.rma,
   ## (2) Subgroup analysis with common tau-squared (three-level model)
   ##
   ##
+  
   if (!missing(subgroup.rma) && is.mlm) {
     n.methci <- length(x$method.random.ci)
     ##
@@ -614,10 +653,8 @@ subgroup <- function(x, tau.preset = NULL, subgroup.rma,
     n.methpi <- length(method.predict)
     ##
     for (i in seq_len(n.methpi)) {
-      df.i <-
-        ifelse(method.predict[i] == "HTS" & k.w >= 3, k.w - 2,
-        ifelse(method.predict[i] == "S", Inf, NA))
-      ##
+      df.i <- set_df_predict(method.predict[i], k.w)
+      #
       ci.p <- ci(TE.random.w, seTE.predict.w, x$level.predict, df = df.i)
       ##
       if (n.methpi == 1) {
@@ -630,7 +667,10 @@ subgroup <- function(x, tau.preset = NULL, subgroup.rma,
       }
       ##
       sel.p <-
-        !(method.predict[i] == "HTS" & k.w >= 3 | method.predict[i] == "S")
+        !(method.predict[i] == "V" & k.w >= 2 |
+            method.predict[i] == "HTS" & k.w >= 3 |
+            method.predict[i] == "S")
+      #
       if (n.methpi == 1) {
         lower.predict.w[sel.p] <- NA
         upper.predict.w[sel.p] <- NA
@@ -689,6 +729,7 @@ subgroup <- function(x, tau.preset = NULL, subgroup.rma,
   ## (3) Subgroup analysis with common tau-squared (GLMM)
   ##
   ##
+  
   if (!missing(subgroup.rma) && is.glmm) {
     n.methci <- length(x$method.random.ci)
     ##
@@ -808,10 +849,8 @@ subgroup <- function(x, tau.preset = NULL, subgroup.rma,
     n.methpi <- length(method.predict)
     ##
     for (i in seq_len(n.methpi)) {
-      df.i <-
-        ifelse(method.predict[i] == "HTS" & k.w >= 3, k.w - 2,
-        ifelse(method.predict[i] == "S", Inf, NA))
-      ##
+      df.i <- set_df_predict(method.predict[i], k.w)
+      #
       ci.p <- ci(TE.random.w, seTE.predict.w, x$level.predict, df = df.i)
       ##
       if (n.methpi == 1) {
@@ -824,7 +863,10 @@ subgroup <- function(x, tau.preset = NULL, subgroup.rma,
       }
       ##
       sel.p <-
-        !(method.predict[i] == "HTS" & k.w >= 3 | method.predict[i] == "S")
+        !(method.predict[i] == "V" & k.w >= 2 |
+            method.predict[i] == "HTS" & k.w >= 3 |
+            method.predict[i] == "S")
+      #
       if (n.methpi == 1) {
         lower.predict.w[sel.p] <- NA
         upper.predict.w[sel.p] <- NA
@@ -888,6 +930,7 @@ subgroup <- function(x, tau.preset = NULL, subgroup.rma,
   ## (4) Return list with results of subgroup analysis
   ##
   ##
+  
   res <- list(subgroup.levels = levs,
               ##
               k.w = k.w,
